from .app import Terminwind


def run():
    Terminwind.run(title="Terminwind")
